@@ -27,6 +27,8 @@ class RequestsSession(requests.Session):
 class FlowAPIException(Exception):
     pass
 
+class FlowAPIAccessDeniedException(FlowAPIException):
+    pass
 
 class DeployNotFoundException(FlowAPIException):
     pass
@@ -151,6 +153,12 @@ class Deploys(object):
         except requests.exceptions.HTTPError as error:
             if error.response.status_code == 404:
                 raise DeployNotFoundException() from error
+            if error.response.status_code == 401:
+                raise FlowAPIAccessDeniedException(
+                    "Access denied, check if your flow api key is valid"
+                ) from error
+
+            raise error
 
     @staticmethod
     def _assert_filepointer_is_at_beginning(diff_content):
@@ -205,6 +213,7 @@ class Findings(object):
 
         data = {
             'flow_project_id': project_code,
+            'flow_deploy_id': kwargs.get('deploy_id'),
             'report': finding_report,
         }
 
