@@ -1,5 +1,6 @@
 import yaml
 import tempfile
+import os 
 
 from .source_code_scanner import SourceCodeScanner
 from .exceptions import SourceCodeScannerException
@@ -13,7 +14,7 @@ class SCC(SourceCodeScanner):
 
     @property
     def repository(self):
-        return 'convisoappsec/scc'
+        return 'public.ecr.aws/e1z1q7t1/scc'
 
     @property
     def tag(self):
@@ -21,7 +22,8 @@ class SCC(SourceCodeScanner):
 
     @property
     def container_source_dir(self):
-        return '/code'
+        bitbucket = os.getenv('BITBUCKET_CLONE_DIR')
+        return bitbucket or '/code'
 
     def _read_scan_stdout(self, stdout_generator):
         with tempfile.TemporaryFile() as yaml_output:
