@@ -69,12 +69,30 @@ def versioning_style(
         previous_version = result.previous_version
         diff_content = None
 
+        current_commit = current_version.get('commit')
+        previous_commit = previous_version.get('commit')
+
+        if previous_commit == current_commit:
+            import sys
+            click.echo(
+                "Previous commit ({0}) and Current commit ({1}) are the same, nothing to do.".format(
+                    previous_commit, current_commit
+                ),
+                file=sys.stderr
+            )
+            return
+
         if attach_diff:
             diff_content = git_adapter.diff(
-                    previous_version.get('commit'),
-                    current_version.get('commit'),
+                previous_commit,
+                current_commit,
             )
 
+        deploy_metrics = git_adapter.diff_stats(
+            previous_commit,
+            current_commit,
+        ).dict
+
         flow = flow_context.create_flow_api_client()
 
         deploy = flow.deploys.create(
@@ -82,6 +100,7 @@ def versioning_style(
             current_version=current_version,
             previous_version=previous_version,
             diff_content=diff_content,
+            metrics=deploy_metrics,
             project_metrics=project_metrics(repository_dir)
         )
 
