@@ -58,6 +58,16 @@ def values(
             except api.DeployNotFoundException:
                 previous_commit = git_adapter.empty_repository_tree_commit
 
+        if previous_commit == current_commit:
+            import sys
+            click.echo(
+                "Previous commit ({0}) and Current commit ({1}) are the same, nothing to do.".format(
+                    previous_commit, current_commit
+                ),
+                file=sys.stderr
+            )
+            return
+            
         diff_content = None
 
         if attach_diff:
@@ -66,11 +76,17 @@ def values(
                 current_commit,
             )
 
+        deploy_metrics = git_adapter.diff_stats(
+            previous_commit,
+            current_commit,
+        ).dict
+
         deploy = flow.deploys.create(
             project_code,
             current_version={'commit': current_commit},
             previous_version={'commit': previous_commit},
             diff_content=diff_content,
+            metrics=deploy_metrics,
             project_metrics=project_metrics(repository_dir)
         )
 
