@@ -3,14 +3,16 @@ from pathlib import Path
 import tempfile
 import tarfile
 import docker
+import os
 
+bitbucket = os.getenv('BITBUCKET_CLONE_DIR')
 
 class SASTBox(object):
     REGISTRY = 'docker.convisoappsec.com'
     REPOSITORY_NAME = 'sastbox'
     DEFAULT_TAG = 'latest'
     CONTAINER_REPORTS_DIR = '/reports'
-    CONTAINER_CODE_DIR = '/code'
+    CONTAINER_CODE_DIR = bitbucket or '/code'
     WORKSPACE_REPORT_PATH = ["reports"]
     JSON_REPORT_PATTERN = '*.jsonreporter*.json'
     SUCCESS_EXIT_CODE = 0
@@ -45,12 +47,14 @@ class SASTBox(object):
 
     @property
     def size(self):
-        registry_data = self.docker.images.get_registry_data(
-            self.image
-        )
-
-        descriptor = registry_data.attrs.get('Descriptor', {})
-        return descriptor.get('size') * 1024 * 1024
+        try:
+            registry_data = self.docker.images.get_registry_data(
+                self.image
+            )
+            descriptor = registry_data.attrs.get('Descriptor', {})
+            return descriptor.get('size') * 1024 * 1024
+        except docker.errors.APIError:
+            return 6300 * 1024 * 1024
 
     def pull(self):
         '''
